==> phpgroupware-0.9.16.011.tbz: www/data-dist/phpgroupware/phpsysinfo/includes/lang/big5.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: big5.php,v 1.1.2.1 2003/11/01 22:10:21 skwashd Exp $
$charset                = 'big5';
$text['title']          = 'tθT';

$text['vitals']         = 'tθ귽';
$text['hostname']       = 'DW';
$text['ip']             = 'Listening IP';
$text['kversion']       = '֤ߪ';
$text['uptime']         = 'w}ɶ';
$text['users']          = 'nJH';
$text['loadavg']        = 'tέt';

$text['hardware']       = 'w귽';
$text['numcpu']         = 'B⤸';
$text['cpumodel']       = 'CPU';
$text['mhz']            = 'u@Wv';
$text['cache']          = '֨jp';
$text['bogomips']       = '޿B⤸';
$text['pci']            = 'PCI ';
$text['ide']            = 'IDE ';
$text['scsi']           = 'SCSI ';

$text['netusage']       = 'ʥ]';
$text['device']         = '';
$text['received']       = '';
$text['sent']           = 'ǰe';
$text['errors']         = '~/';

$text['connections']	= 'Established Network Connections';

$text['memusage']       = 'O귽';
$text['phymem']         = 'O';
$text['swap']           = 'O';

$text['fs']             = 'wJɮרt';
$text['mount']          = 'J';
$text['partition']      = 'ϰ';

$text['percent']        = 'ϥΦʤ';
$text['type']           = '榡';
$text['free']           = 'žl';
$text['used']           = 'w';
$text['size']           = 'jp';
$text['totals']         = 'Xp';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'L';

$text['capacity']       = 'Capacity'; 

$text['template']       = '˦';
$text['language']       = 'y';
$text['submit']         = 'Tw';
$text['created']        = 'Created by';

$text['days']           = '';
$text['hours']          = 'p';
$text['minutes']        = '';
?>

==> phpgroupware-0.9.16.017.tbz: www/data-dist/phpgroupware/phpsysinfo/includes/lang/big5.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: big5.php 21052 2010-03-25 22:44:08Z Caeies $
//
$charset                = 'big5';
$text['title']          = 'tθT';

$text['vitals']         = 'tθ귽';
$text['hostname']       = 'DW';
$text['ip']             = 'D~ IP';
$text['kversion']       = '֤ߪ';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'w}ɶ';
$text['users']          = 'nJH';
$text['loadavg']        = 'tέt';

$text['hardware']       = 'w귽';
$text['numcpu']         = 'B⤸';
$text['cpumodel']       = 'CPU';
$text['cpuspeed']       = 'u@Wv';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = '֨jp';
$text['bogomips']       = '޿B⤸';

$text['pci']            = 'PCI ';
$text['ide']            = 'IDE ';
$text['scsi']           = 'SCSI ';
$text['usb']            = 'USB ';

$text['netusage']       = 'ʥ]';
$text['device']         = '';
$text['received']       = '';
$text['sent']           = 'ǰe';
$text['errors']         = '~/';

$text['connections']    = 'Established Network Connections';

$text['memusage']       = 'O귽';
$text['phymem']         = 'O';
$text['swap']           = 'O(Ϻиm)';

$text['fs']             = 'wJɮרt';
$text['mount']          = 'J';
$text['partition']      = 'ϰ';

$text['percent']        = 'ϥΦʤ';
$text['type']           = '榡';
$text['free']           = 'žl';
$text['used']           = 'w';
$text['size']           = 'jp';
$text['totals']         = 'Xp';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'L';

$text['capacity']       = 'eq';

$text['template']       = '˦';
$text['language']       = 'y';
$text['submit']         = 'Tw';
$text['created']        = 'ͥ';
$text['locale']         = 'zh_TW.Big5';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = '';
$text['hours']          = 'p';
$text['minutes']        = '';

$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degreeC']        = '&deg;C';
$text['degreeF']        = '&deg;F';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

?>
